==> ui-react-1.0.84.tgz: package/esm/Tab/Tab.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
const _excluded = ["tonal", "color", "version", "size", "value", "onChange", "active", "index", "name", "label", "icon", "iconPosition", "activateOnFocus", "disabled", "onBlur", "onFocus", "LineProps", "Component", "className", "children"];
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
import React from 'react';
import { is } from '@onesy/utils';
import { classNames, style as styleMethod, useOnesyTheme } from '@onesy/style-react';
import TypeElement from '../Type';
import SurfaceElement from '../Surface';
import LineElement from '../Line';
import InteractionElement from '../Interaction';
import { staticClassName } from '../utils';
const useStyle = styleMethod(theme => ({
  root: {
    // Reset
    fontFamily: 'inherit',
    '-webkit-appearance': 'none',
    appearance: 'none',
    background: 'transparent',
    border: 'none',
    fontSize: '100%',
    lineHeight: '1.15',
    margin: '0',
    overflow: 'visible',
    textTransform: 'none',
    position: 'relative',
    flex: '0 0 auto',
    alignSelf: 'stretch',
    userSelect: 'none',
    cursor: 'pointer',
    opacity: theme.palette.visual_contrast.default.opacity.secondary,
    transition: theme.methods.transitions.make('opacity')
  },
  size_small: {
    padding: `${theme.methods.space.value(1.5, 'px')} ${theme.methods.space.value(3, 'px')}`,
    minWidth: '40px',
    maxWidth: '200px'
  },
  size_regular: {
    padding: `${theme.methods.space.value(2, 'px')} ${theme.methods.space.value(4, 'px')}`,
    minWidth: '70px',
    maxWidth: '240px'
  },
  size_large: {
    padding: `${theme.methods.space.value(2.5, 'px')} ${theme.methods.space.value(5, 'px')}`,
    minWidth: '100px',
    maxWidth: '280px'
  },
  type_small: {
    maxHeight: '2rem'
  },
  type_regular: {
    maxHeight: '2.15rem'
  },
  type_large: {
    maxHeight: '2.6rem'
  },
  line: {
    overflow: 'hidden'
  },
  active: {
    opacity: '1'
  },
  disabled: {
    pointerEvents: 'none',
    opacity: theme.palette.visual_contrast.default.opacity.disabled,
    cursor: 'default'
  }
}), {
  name: 'onesy-Tab'
});
const Tab = /*#__PURE__*/React.forwardRef((props_, ref) => {
  const theme = useOnesyTheme();
  const props = React.useMemo(() => _objectSpread(_objectSpread(_objectSpread({}, theme?.ui?.elements?.all?.props?.default), theme?.ui?.elements?.onesyTab?.props?.default), props_), [props_]);
  const Line = React.useMemo(() => theme?.elements?.Line || LineElement, [theme]);
  const Type = React.useMemo(() => theme?.elements?.Type || TypeElement, [theme]);
  const Surface = React.useMemo(() => theme?.elements?.Surface || SurfaceElement, [theme]);
  const Interaction = React.useMemo(() => theme?.elements?.Interaction || InteractionElement, [theme]);
  const {
      tonal = true,
      color = 'primary',
      version = 'primary',
      size = 'regular',
      value,
      onChange,
      active,
      index,
      name,
      label: label_,
      icon,
      iconPosition = 'start',
      activateOnFocus,
      disabled,
      onBlur: onBlur_,
      onFocus: onFocus_,
      LineProps = {},
      Component = 'button',
      className,
      children
    } = props,
    other = _objectWithoutProperties(props, _excluded);
  const {
    classes
  } = useStyle();
  const [focus, setFocus] = React.useState(false);
  const label = name !== undefined ? name : label_;
  const onBlur = React.useCallback(event => {
    if (!disabled) setFocus(false);
    if (is('function', onBlur_)) onBlur_(event);
  }, [disabled, onBlur_]);
  const onFocus = React.useCallback(event => {
    if (!disabled) {
      setFocus(true);
      if (activateOnFocus) onChange(value, index);
    }
    if (is('function', onFocus_)) onFocus_(event);
  }, [activateOnFocus, value, disabled, onFocus_]);
  if (icon !== undefined) {
    LineProps.direction = iconPosition === 'start' ? 'row' : iconPosition === 'top' ? 'column' : iconPosition === 'end' ? 'row-reverse' : 'column-reverse';
  }
  let typeVersion = 'l2';
  if (size === 'large') typeVersion = 'l1';else if (size === 'small') typeVersion = 'l3';
  return /*#__PURE__*/React.createElement(Surface, _extends({
    ref: ref,
    tabIndex: !disabled ? 0 : -1,
    tonal: tonal,
    color: color,
    onBlur: onBlur,
    onFocus: onFocus,
    role: "tab",
    "aria-selected": active,
    "data-onesy-tab-value": value,
    Component: Component,
    className: classNames([staticClassName('Tab', theme) && ['onesy-Tab-root', `onesy-Tab-version-${version}`, `onesy-Tab-size-${size}`, active && `onesy-Tab-active`, disabled && `onesy-Tab-disabled`], className, classes.root, classes[`size_${size}`], active && classes.active, disabled && classes.disabled])
  }, other), /*#__PURE__*/React.createElement(Interaction, {
    pulse: focus
  }), /*#__PURE__*/React.createElement(Line, _extends({
    gap: 1,
    direction: "row",
    align: "center",
    justify: "center"
  }, LineProps, {
    className: classNames([staticClassName('Tab', theme) && ['onesy-Tab-line'], LineProps?.className, classes.line])
  }), icon, label !== undefined && (is('simple', label) ? /*#__PURE__*/React.createElement(Type, {
    version: typeVersion,
    className: classNames([staticClassName('Tab', theme) && ['onesy-Tab-type'], classes[`type_${size}`]])
  }, label) : label), children !== undefined && (is('simple', children) ? /*#__PURE__*/React.createElement(Type, {
    version: typeVersion,
    className: classNames([staticClassName('Tab', theme) && ['onesy-Tab-type'], classes[`type_${size}`]])
  }, children) : children)));
});
Tab.displayName = 'onesy-Tab';
export default Tab;

==> ui-react-1.0.91.tgz: package/esm/Tab/Tab.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
const _excluded = ["tonal", "color", "version", "size", "value", "onChange", "active", "index", "name", "label", "icon", "iconPosition", "activateOnFocus", "tooltip", "disabled", "onBlur", "onFocus", "LineProps", "TooltipProps", "Component", "className", "children"];
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
import React from 'react';
import { is } from '@onesy/utils';
import { classNames, style as styleMethod, useOnesyTheme } from '@onesy/style-react';
import TooltipElement from '../Tooltip';
import TypeElement from '../Type';
import SurfaceElement from '../Surface';
import LineElement from '../Line';
import InteractionElement from '../Interaction';
import { staticClassName } from '../utils';
const useStyle = styleMethod(theme => ({
  root: {
    // Reset
    fontFamily: 'inherit',
    '-webkit-appearance': 'none',
    appearance: 'none',
    background: 'transparent',
    border: 'none',
    fontSize: '100%',
    lineHeight: '1.15',
    margin: '0',
    overflow: 'visible',
    textTransform: 'none',
    position: 'relative',
    flex: '0 0 auto',
    alignSelf: 'stretch',
    userSelect: 'none',
    cursor: 'pointer',
    opacity: theme.palette.visual_contrast.default.opacity.secondary,
    transition: theme.methods.transitions.make('opacity')
  },
  size_small: {
    padding: `${theme.methods.space.value(1.5, 'px')} ${theme.methods.space.value(3, 'px')}`,
    minWidth: '40px',
    maxWidth: '200px'
  },
  size_regular: {
    padding: `${theme.methods.space.value(2, 'px')} ${theme.methods.space.value(4, 'px')}`,
    minWidth: '70px',
    maxWidth: '240px'
  },
  size_large: {
    padding: `${theme.methods.space.value(2.5, 'px')} ${theme.methods.space.value(5, 'px')}`,
    minWidth: '100px',
    maxWidth: '280px'
  },
  type_small: {
    maxHeight: '2rem'
  },
  type_regular: {
    maxHeight: '2.15rem'
  },
  type_large: {
    maxHeight: '2.6rem'
  },
  line: {
    overflow: 'hidden'
  },
  active: {
    opacity: '1'
  },
  disabled: {
    pointerEvents: 'none',
    opacity: theme.palette.visual_contrast.default.opacity.disabled,
    cursor: 'default'
  }
}), {
  name: 'onesy-Tab'
});
const Tab = /*#__PURE__*/React.forwardRef((props_, ref) => {
  const theme = useOnesyTheme();
  const props = React.useMemo(() => _objectSpread(_objectSpread(_objectSpread({}, theme?.ui?.elements?.all?.props?.default), theme?.ui?.elements?.onesyTab?.props?.default), props_), [props_]);
  const Line = React.useMemo(() => theme?.elements?.Line || LineElement, [theme]);
  const Type = React.useMemo(() => theme?.elements?.Type || TypeElement, [theme]);
  const Surface = React.useMemo(() => theme?.elements?.Surface || SurfaceElement, [theme]);
  const Interaction = React.useMemo(() => theme?.elements?.Interaction || InteractionElement, [theme]);
  const Tooltip = React.useMemo(() => theme?.elements?.Tooltip || TooltipElement, [theme]);
  const {
      tonal = true,
      color = 'primary',
      version = 'primary',
      size = 'regular',
      value,
      onChange,
      active,
      index,
      name,
      label: label_,
      icon,
      iconPosition = 'start',
      activateOnFocus,
      tooltip,
      disabled,
      onBlur: onBlur_,
      onFocus: onFocus_,
      LineProps = {},
      TooltipProps,
      Component = 'button',
      className,
      children
    } = props,
    other = _objectWithoutProperties(props, _excluded);
  const {
    classes
  } = useStyle();
  const [focus, setFocus] = React.useState(false);
  const label = name !== undefined ? name : label_;
  const onBlur = React.useCallback(event => {
    if (!disabled) setFocus(false);
    if (is('function', onBlur_)) onBlur_(event);
  }, [disabled, onBlur_]);
  const onFocus = React.useCallback(event => {
    if (!disabled) {
      setFocus(true);
      if (activateOnFocus) onChange(value, index);
    }
    if (is('function', onFocus_)) onFocus_(event);
  }, [activateOnFocus, value, disabled, onFocus_]);
  if (icon !== undefined) {
    LineProps.direction = iconPosition === 'start' ? 'row' : iconPosition === 'top' ? 'column' : iconPosition === 'end' ? 'row-reverse' : 'column-reverse';
  }
  let typeVersion = 'l2';
  if (size === 'large') typeVersion = 'l1';else if (size === 'small') typeVersion = 'l3';
  const hasTooltip = ![null, undefined].includes(tooltip);
  const Wrapper = hasTooltip ? Tooltip : React.Fragment;
  const wrapperProps = hasTooltip ? _objectSpread({
    name: tooltip
  }, TooltipProps) : undefined;
  return /*#__PURE__*/React.createElement(Wrapper, wrapperProps, /*#__PURE__*/React.createElement(Surface, _extends({
    ref: ref,
    tabIndex: !disabled ? 0 : -1,
    tonal: tonal,
    color: color,
    onBlur: onBlur,
    onFocus: onFocus,
    role: "tab",
    "aria-selected": active,
    "data-onesy-tab-value": value,
    Component: Component,
    className: classNames([staticClassName('Tab', theme) && ['onesy-Tab-root', `onesy-Tab-version-${version}`, `onesy-Tab-size-${size}`, active && `onesy-Tab-active`, disabled && `onesy-Tab-disabled`], className, classes.root, classes[`size_${size}`], active && classes.active, disabled && classes.disabled])
  }, other), /*#__PURE__*/React.createElement(Interaction, {
    pulse: focus
  }), /*#__PURE__*/React.createElement(Line, _extends({
    gap: 1,
    direction: "row",
    align: "center",
    justify: "center"
  }, LineProps, {
    className: classNames([staticClassName('Tab', theme) && ['onesy-Tab-line'], LineProps?.className, classes.line])
  }), icon, label !== undefined && (is('simple', label) ? /*#__PURE__*/React.createElement(Type, {
    version: typeVersion,
    className: classNames([staticClassName('Tab', theme) && ['onesy-Tab-type'], classes[`type_${size}`]])
  }, label) : label), children !== undefined && (is('simple', children) ? /*#__PURE__*/React.createElement(Type, {
    version: typeVersion,
    className: classNames([staticClassName('Tab', theme) && ['onesy-Tab-type'], classes[`type_${size}`]])
  }, children) : children))));
});
Tab.displayName = 'onesy-Tab';
export default Tab;
